$   ver = 'F$VERIFY(0)
$   GOTO COPYTREES
$!
$!	COPYTREES.COM
$!
$!	Author:	J. L. BINGHAM
$!		ManTech International
$!		2320 Mill Road
$!		Alexandria, VA 22314
$!		(703) 838-5600
$!
$!	Adapted by: Alan L. Zirkle
$!		    Naval Surface Weapons Center
$!		    Code K53
$!		    Dahlgren, VA 22448
$!		    (703) 663-8023
$!
$!	This version is new for the Spring '87 tapes.
$!
$!	This command procedure is designed to make the copying of directory
$!  trees containing VAX Systems SIG Symposia tapes easy and consistent.  A
$!  small file suitable for a label is produced; it contains escape sequen-
$!  ces for LA120 small print.  This file can be copied to OPA0 if you have
$!  an 11-7xx.  The file is given a name of ddmmmhhmm.LBL, where the begin-
$!  ning day/month/hour/minute of the copy is encoded in the name.
$!
$!	This procedure assumes it is being run on a VT100-compatible screen,
$!  since it contains many escape sequences to do screen formatting.
$!
$!	The symposia tapes are assumed to be in directory trees named
$!
$!			dev:[VAXnnn]
$!
$!  where 'dev' is either a device name or a rooted directory name.  For ex-
$!  ample, if you have the tapes in MYDISK:[A.B.VAXnnn], then you should
$!  define a logical name (such as "DECUS") like:
$!
$!	$ DEFINE DECUS 'F$TRNLNM("MYDISK")'[A.B.] /TRAN=(TERM,CON)
$!
$!  If you build the tapes in batch mode, this definition should be in your
$!  LOGIN.COM (or SYLOGIN.COM or /SYSTEM in SYSTARTUP.COM).
$!
$!	We assume that the [VAX000...] directory tree exists and optionally
$!  copies it to every tape made.  It also assumes that the symposia tapes
$!  are in directory trees named
$!
$!			[VAX86A...], [VAX86B...], etc.
$!
$!  When you enter one of these names, you do not use brackets or ellipses.
$!
$!	When it asks you for the name of the output tape to use, you can
$!  enter an actual device name ("MFA0", "$1$MSA0") or ask for a generic
$!  assignment ("TU78/GEN", "TU77,TU78/GEN").
$!
$!  Normal usage:  (a) 1600 bpi 9-track tapes
$!
$!	Two 2400-foot reels contain a symposium set; the first reel con-
$!	tains the VAX000 tree and the VAXnnA (or nnC) tree; the second
$!	reel contains the VAXnnB (or nnD) tree.  Two separate invocations
$!	of COPYTREES is necessary.
$!
$!		   (b) 6250 bpi 9-track tape
$!
$!	One 2400 foot reel contains a symposium set--The VAX000 tree, the
$!	VAXnnA (or nnC) tree, and the VAXnnB (or nnD) tree.
$!
$!		   (c) TK50 cartridge
$!
$!	One cartridge contains a symposium set--The VAX000 tree, the
$!	VAXnnA (or nnC) tree, and the VAXnnB (or nnD) tree.  Any density
$!	entered is ignored.
$!
$!	To configure this procedure for your system, edit the lines con-
$!  taining the string '!##'.
$!
$!		    THE FOLLOWING THREE SYMBOL
$!		 VALUES ARE INSTALLATION-SPECIFIC
$!				|
$!				|
$!				V
$ COPYTREES:
$   VAXSIG$LABL =  "arimis:[bingham]"	!##		! Where label file goes
$!					!		! (use null if unneeded)
$   VAXSIG$SHOP =  "Joe Bingham (703) 838-5600"	!##	! Who is responsible.
$   VAXSIG$VOLN =  "archive"			  !##	! Default disk volume,
$!							!  (if COPYTREES mounts
$!							!   disk).
$   procdir = F$ELEMENT(0,"]",F$ENV("PROCEDURE")) + "]"
$!
$   ECHO = "WRITE SYS$OUTPUT"
$!
$   IF F$MODE() .EQS. "BATCH" THEN  GOTO BATCH
$!
$   IF F$TYPE(VAXSIG$DISK) .NES. "" THEN  GOTO DISPLAY
$!
$!	THE FOLLOWING SIX VALUES ARE DEFAULTS AND CAN BE OVERRIDDEN
$!	AT EXECUTION TIME; ANY NEW SETTINGS ARE SAVED UNTIL LOGOUT.
$!
$   VAXSIG$DISK == "archive" !##	! Disk or root containing VAXxxx directories
$   VAXSIG$TAPE == "MFA0"  !##	! Mag tape drive to use
$   VAXSIG$DENS == "1600"  !##	! Mag tape density to use
$   VAXSIG$VAX0 == "Y"	   !##	! Copy VAX000 directory?
$   VAXSIG$MODE == "i"	   !##	! Copy mode (I or B for Interactive or Batch)
$   VAXSIG$VERF == "N"	   !##	! Do verify passes on BACKUPs?
$!
$!  VAXSIG$FRST			! First directory to copy (not incl. VAX000)
$!  VAXSIG$LAST			! Last directory to copy
$!  VAXSIG$WHOM			! For whom the tape is being made (for label)
$!
$ DISPLAY:
$   IF p1 .NES. "" THEN  VAXSIG$TAPE == p1	! You can optionally specify
$   IF p2 .NES. "" THEN  VAXSIG$VAX0 == p2	!  these via parameters.
$!
$   x = ""
$   IF .NOT. VAXSIG$VAX0 THEN  x = "[1;5mNOT[m "
$   y = "interactively"
$   IF VAXSIG$MODE .EQS. "B" THEN  y = "[1;5mIN BATCH MODE[m"
$   z = " with"
$   IF .NOT. VAXSIG$VERF THEN  z = "[1;5mWITHOUT[m"
$!
$   ECHO " "
$   ECHO "Defaults are:  Source disk [1m ",VAXSIG$DISK," [m"
$   ECHO "               Output tape [1m ",VAXSIG$TAPE," [m"
$   ECHO "               Tape density[1m ",VAXSIG$DENS," [m"
$   ECHO "         The VAX000 tree will ",x,"be copied."
$   ECHO "       The copy will be done ",y,","
$   ECHO "	     ",z," verify passes."
$!
$   INQUIRE x "
  Do you want to change the defaults (Y/N) [N]"
$   IF .NOT. x THEN  GOTO BEGIN
$!
$   INQUIRE x "
	Enter Source disk  [''VAXSIG$DISK']"
$   x = x - ":"
$   IF x .NES. "" THEN  VAXSIG$DISK == x
$   INQUIRE x "
	Enter Output tape  [''VAXSIG$TAPE']"
$   IF x .NES. "" THEN  VAXSIG$TAPE == x
$   INQUIRE x "
	Enter Tape density [''VAXSIG$DENS']"
$   IF x .NES. "" THEN  VAXSIG$DENS == x
$   INQUIRE x "
	Include the VAX000 tree (Y/N) [''VAXSIG$VAX0']"
$   IF x .NES. "" THEN  VAXSIG$VAX0 == F$EXTRACT(0,1,x)
$   INQUIRE x "
    Copy interactively or batch (I/B) [''VAXSIG$MODE']"
$   IF x .NES. "" THEN  VAXSIG$MODE == F$EXTRACT(0,1,x)
$   INQUIRE x "
    Run verify passes on BACKUPs (Y/N) [''VAXSIG$VERF']"
$   IF x .NES. "" THEN  VAXSIG$VERF == F$EXTRACT(0,1,x)
$   GOTO DISPLAY
$!
$ BEGIN:
$   IF .NOT. F$GETDVI(VAXSIG$DISK,"EXISTS") THEN  GOTO NOSUCH
$   IF F$GETDVI(VAXSIG$DISK,"MNT") THEN  GOTO SPECIFY
$!
$ NOSUCH:
$   ECHO "
Disk ",VAXSIG$DISK," must be mounted.
"
$!
$   INQUIRE x "Do you want COPYTREES to do the mount (Y/N) [Y]"
$   IF .NOT. x .AND. x .NES. "" THEN  GOTO END
$!
$   INQUIRE x "
Enter volume label [''VAXSIG$VOLN']"
$   IF x .EQS. "" THEN  x = VAXSIG$VOLN
$!
$   ECHO ""
$   MOUNT /SHARE 'VAXSIG$DISK' 'x'
$   GOTO BEGIN
$!
$ SPECIFY:
$   notcount = ", not counting VAX000"
$   IF .NOT. VAXSIG$VAX0 THEN  notcount = ""
$!
$   INQUIRE VAXSIG$FRST "
Enter name of first tree to be copied''notcount'"
$   IF VAXSIG$FRST .EQS. "" THEN GOTO SPECIFY
$!
$   INQUIRE VAXSIG$LAST -
	    "
Enter name of last tree to be copied (default ''VAXSIG$FRST')"
$   IF VAXSIG$LAST .EQS. "" THEN VAXSIG$LAST = VAXSIG$FRST
$!
$   IF VAXSIG$LABL .NES. "" THEN -
		INQUIRE VAXSIG$WHOM "
For whom are you making this tape"
$!
$   IF F$GETDVI(VAXSIG$TAPE,"EXISTS") THEN -
		INQUIRE OK "
Load a tape on ''VAXSIG$TAPE' and enter <CR>"
$!
$   ECHO " "
$   IF VAXSIG$MODE .NES. "B" THEN  GOTO PROCEED
$!
$   queue = "SYS$BATCH"	      !## Insert code here to use different batch queue
$   queue = F$EXTRACT(0,2,F$GETSYI("NODENAME")) + "_OPERATIONS"		!NSWC
$!
$   SUBMIT COPYTREES /PARAM=('VAXSIG$DISK',"''VAXSIG$TAPE'",'VAXSIG$DENS',-
			     'VAXSIG$VAX0',  'VAXSIG$FRST' ,'VAXSIG$LAST',-
			     'VAXSIG$VERF',"''VAXSIG$WHOM'") /QUEUE='queue'
$   ECHO " "
$   GOTO EXIT2
$!
$ PROCEED:
$   ON WARNING   THEN  GOTO ERROR
$   ON CONTROL_Y THEN  GOTO ERROR
$!
$   ALLOCATE 'VAXSIG$TAPE' SIG$TAPE
$!
$   densityqual = "/DENSITY=" + VAXSIG$DENS
$   IF F$GETDVI("SIG$TAPE:","DEVTYPE") .EQ. 10 THEN  densityqual = ""  ! TK50
$!
$!  The following MOUNT, DISMOUNT is in case operator intervention is required.
$!
$   MOUNT /FOREIGN SIG$TAPE: -
		/COMMENT="----- Load output tape for VAX SIG TAPECOPY -----"
$   DISMOUNT /NOUNLOAD SIG$TAPE:
$   INITIALIZE 'densityqual' SIG$TAPE: VAXSIG
$   ECHO "Initialized ",F$TRNLNM("SIG$TAPE")," as VAXSIG"
$   MOUNT /FOREIGN 'densityqual' SIG$TAPE:
$!
$   error = "F"					! No error has occurred
$   errcount = F$GETDVI("SIG$TAPE:","ERRCNT")	! Initial tape error count
$!
$   time = F$EXTRACT(0,17,F$TIME())
$   ECHO " "
$!
$!  Format of label file name is ddmmmhhmm.LBL
$!
$   IF VAXSIG$LABL .EQS. "" THEN  GOTO NOLABEL
$!
$   label = F$EXTRACT(0,6,time) + F$EXTRACT(12,5,time) - "-" - ":" - " "
$   label = VAXSIG$LABL + label + ".LBL"
$!
$   OPEN /WRITE /error=label_error LABEL 'label'
$!
$   WL = "WRITE LABEL"
$!
$   WL "[4w[2z"			! LA120 formatting
$   WL "This tape is for:  ",VAXSIG$WHOM,"

"
$   WL "_____________________________________________________________"
$   WL "|							    |"
$   WL "|             VAX SYSTEMS SIG TAPE COPY PROJECT		    |"
$   WL "|							    |"
$   WL "|  TAPE IS IN BACKUP /INTERCHANGE FORMAT, ",VAXSIG$DENS," BPI DENSITY  |"
$   WL "|  SEE [VAX000]0README.1ST       ",VAXSIG$SHOP," |"
$   WL "|							    |"
$   WL "|  THIS TAPE CONTAINS:                   ",time,"  |"
$   WL "|    ROOT DIRECTORY     SAVE-SET NAME      APPROX BLOCKS    |"
$!
$ NOLABEL:
$   ECHO " "
$   IF .NOT. VAXSIG$VAX0 THEN  GOTO LOOP
$!
$   @'procdir'TREETAPE [VAX000...] /REWIND
$!
$ LOOP:
$   candidate = F$SEARCH(VAXSIG$DISK+":[000000]VAX*.DIR")
$   IF candidate .EQS. "" THEN  GOTO EXIT
$!
$   found = F$PARSE(candidate,,,"NAME")
$!
$   IF found .LTS. VAXSIG$FRST THEN  GOTO LOOP
$   IF found .GTS. VAXSIG$LAST THEN  GOTO EXIT
$!
$   @'procdir'TREETAPE ['found'...] /NOREWIND
$   GOTO LOOP
$!
$ BATCH:
$   SET VERIFY
$   VAXSIG$DISK == P1
$   VAXSIG$TAPE == P2
$   VAXSIG$DENS == P3
$   VAXSIG$VAX0 == P4
$   VAXSIG$FRST == P5
$   VAXSIG$LAST == P6
$   VAXSIG$VERF == P7
$   VAXSIG$WHOM == P8
$   GOTO PROCEED
$!
$ label_error:
$	echo "******COPY INCOMPLETE******"
$	echo "Have your taylored COPYTREES.COM to your installation?"
$	echo "If not edit the lines containing ""!##"""
$	goto exit2
$ ERROR:
$   ECHO "******COPY INCOMPLETE******"
$   IF F$LOGICAL("LABEL") .EQS. "" THEN  GOTO EXIT2
$   error = "Y"
$!
$ EXIT:
$   DUMMY = 'F$VERIFY(0)
$!
$   IF F$TRNLNM("LABEL") .EQS. "" THEN  GOTO NOLABEL2
$   WL "|___________________________________________________________|"
$   WL "[w[z"	! LA120 escape sequences
$   CLOSE LABEL
$!
$ NOLABEL2:
$   IF error THEN  GOTO EXIT2
$!
$   errcount = F$GETDVI("SIG$TAPE:","ERRCNT") - errcount
$   IF errcount .LE. 0 THEN  GOTO EXIT1
$!
$   IF F$MODE() .EQS. "BATCH" THEN  GOTO B_ERR
$!
$   ECHO "
[1;7m     There were ",errcount," device errors",-
					" writing the tape     [m
"
$   GOTO EXIT1
$!
$ B_ERR:
$   ECHO "
======================================================"
$   ECHO "     There were ",errcount," device errors writing the tape"
$   ECHO "======================================================
"
$!
$ EXIT1:
$   SHOW TIME
$   label = F$SEARCH(label)
$   ECHO "
 Label Information is ",label," 
"
$!
$ EXIT2:
$   SET NOON
$   ON CONTROL_Y THEN CONTINUE
$   IF .NOT. F$GETDVI("SIG$TAPE:","EXISTS") THEN  GOTO END
$   IF F$GETDVI("SIG$TAPE:","MNT") THEN  DISMOUNT SIG$TAPE:
$   DEALLOCATE SIG$TAPE:
$   DEASSIGN SIG$TAPE
$!
$ END:
$   IF ver THEN  SET VERIFY
